# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.samplemetadatasample import Samplemetadatasample

class TestSamplemetadatasample(unittest.TestCase):
    """Samplemetadatasample unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Samplemetadatasample:
        """Test Samplemetadatasample
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Samplemetadatasample`
        """
        model = Samplemetadatasample()
        if include_optional:
            return Samplemetadatasample(
                id = '',
                name = '',
                description = '',
                created_by = '',
                investigation_ids = '',
                icat_sample_id = '',
                icat_sample_a_form_id = '',
                metadata = [
                    icat_plus_client.models.samplemetadata.samplemetadata(
                        _id = '', 
                        name = '', 
                        value = [
                            ''
                            ], )
                    ],
                related_items = [
                    icat_plus_client.models.relateditem.relateditem(
                        _id = '', 
                        related_sample = icat_plus_client.models.samplemetadatasimplifiedsample.samplemetadatasimplifiedsample(
                            _id = '', 
                            name = '', ), 
                        relation_type = '', )
                    ]
            )
        else:
            return Samplemetadatasample(
                name = '',
        )
        """

    def testSamplemetadatasample(self):
        """Test Samplemetadatasample"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.parcel import Parcel

class TestParcel(unittest.TestCase):
    """Parcel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Parcel:
        """Test Parcel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Parcel`
        """
        model = Parcel()
        if include_optional:
            return Parcel(
                id = '',
                shipment_id = '',
                name = '',
                investigation_id = 1.337,
                investigation_name = '',
                storage_conditions = '',
                is_reimbursed = True,
                reimbursed_customs_value = 1.337,
                return_instructions = '',
                return_parcel_information = icat_plus_client.models.return_parcel_information.returnParcelInformation(
                    _id = '', 
                    return_type = 'USER_MANAGE_PAPERS', 
                    forwarder_name = '', 
                    forwarder_account = '', 
                    planned_pickup_date = '', ),
                comments = '',
                contains_dangerous_goods = True,
                statuses = [
                    icat_plus_client.models.status.status(
                        _id = '', 
                        status = '', 
                        created_by = '', 
                        created_at = '', 
                        updated_at = '', 
                        created_by_full_name = '', 
                        created_by_email = '', )
                    ],
                shipping_address = icat_plus_client.models.address.address(
                    _id = '', 
                    name = '', 
                    surname = '', 
                    company_name = '', 
                    address = '', 
                    city = '', 
                    region = '', 
                    postal_code = '', 
                    country = '', 
                    email = '', 
                    phone_number = '', 
                    default_courier_account = '', 
                    default_courier_company = '', ),
                return_address = icat_plus_client.models.address.address(
                    _id = '', 
                    name = '', 
                    surname = '', 
                    company_name = '', 
                    address = '', 
                    city = '', 
                    region = '', 
                    postal_code = '', 
                    country = '', 
                    email = '', 
                    phone_number = '', 
                    default_courier_account = '', 
                    default_courier_company = '', ),
                shipping_tracking_information = icat_plus_client.models.tracking_information.trackingInformation(
                    _id = '', 
                    tracking_number = '', 
                    forwarder = '', ),
                return_tracking_information = icat_plus_client.models.tracking_information.trackingInformation(
                    _id = '', 
                    tracking_number = '', 
                    forwarder = '', ),
                description = '',
                type = '',
                current_status = '',
                items = [
                    icat_plus_client.models.item.item(
                        id = '', 
                        name = '', 
                        type = '', 
                        description = '', 
                        comments = '', )
                    ],
                local_contact_names = [
                    ''
                    ],
                content = [
                    icat_plus_client.models.item.item(
                        id = '', 
                        name = '', 
                        type = '', 
                        description = '', 
                        comments = '', )
                    ],
                created_at = '',
                updated_at = '',
                id = '',
                investigation = icat_plus_client.models.investigation.investigation(
                    id = 1.337, 
                    name = '', 
                    start_date = '', 
                    end_date = '', 
                    doi = '', 
                    title = '', 
                    visit_id = '', 
                    release_date = '', 
                    summary = '', 
                    parameters = icat_plus_client.models.parameters.parameters(), 
                    instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                        id = 1.337, 
                        name = '', 
                        instrument_scientists = [
                            icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                name = '', )
                            ], ), 
                    investigation_users = [
                        icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                            role = '', 
                            user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                email = '', 
                                full_name = '', 
                                family_name = '', 
                                name = '', 
                                given_name = '', ), )
                        ], 
                    meta = icat_plus_client.models.meta.meta(
                        page = icat_plus_client.models.meta_page.meta_page(
                            total = 1.337, 
                            total_pages = 1.337, 
                            current_page = 1.337, ), ), 
                    type = icat_plus_client.models.investigation_type.investigation_type(
                        id = 1.337, 
                        create_id = '', 
                        create_time = '', 
                        mod_id = '', 
                        mod_time = '', 
                        description = '', 
                        name = '', ), 
                    can_access_datasets = True, ),
                meta = icat_plus_client.models.meta.meta(
                    page = icat_plus_client.models.meta_page.meta_page(
                        total = 1.337, 
                        total_pages = 1.337, 
                        current_page = 1.337, ), )
            )
        else:
            return Parcel(
                name = '',
                investigation_id = 1.337,
                investigation_name = '',
        )
        """

    def testParcel(self):
        """Test Parcel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.mxsettings import Mxsettings

class TestMxsettings(unittest.TestCase):
    """Mxsettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Mxsettings:
        """Test Mxsettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Mxsettings`
        """
        model = Mxsettings()
        if include_optional:
            return Mxsettings(
                auto_processing_ranking_shell = '',
                auto_processing_ranking_parameter = '',
                auto_processing_ranking_disable_space_group = True,
                scan_type_filters = [
                    ''
                    ],
                cutoffs = icat_plus_client.models.mxcutoffs.mxcutoffs(
                    completeness = icat_plus_client.models.mxshell.mxshell(
                        inner = 1.337, 
                        outer = 1.337, 
                        overall = 1.337, ), 
                    resolution_limit_low = icat_plus_client.models.mxshell.mxshell(
                        inner = 1.337, 
                        outer = 1.337, 
                        overall = 1.337, ), 
                    resolution_limit_high = , 
                    r_meas_all_i_plus_i_minus = , 
                    mean_i_over_sig_i = , 
                    cc_half = , 
                    cc_ano = , )
            )
        else:
            return Mxsettings(
                auto_processing_ranking_shell = '',
                auto_processing_ranking_parameter = '',
                scan_type_filters = [
                    ''
                    ],
                cutoffs = icat_plus_client.models.mxcutoffs.mxcutoffs(
                    completeness = icat_plus_client.models.mxshell.mxshell(
                        inner = 1.337, 
                        outer = 1.337, 
                        overall = 1.337, ), 
                    resolution_limit_low = icat_plus_client.models.mxshell.mxshell(
                        inner = 1.337, 
                        outer = 1.337, 
                        overall = 1.337, ), 
                    resolution_limit_high = , 
                    r_meas_all_i_plus_i_minus = , 
                    mean_i_over_sig_i = , 
                    cc_half = , 
                    cc_ano = , ),
        )
        """

    def testMxsettings(self):
        """Test Mxsettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.doi_api import DOIApi


class TestDOIApi(unittest.TestCase):
    """DOIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DOIApi()

    def tearDown(self) -> None:
        pass

    def test_doi_prefix_suffix_datasets_get(self) -> None:
        """Test case for doi_prefix_suffix_datasets_get

        Returns a set of datasets given a DOI.
        """
        pass

    def test_doi_prefix_suffix_json_datacite_get(self) -> None:
        """Test case for doi_prefix_suffix_json_datacite_get

        Returns a document in a json-datacite format with the description of the DOI
        """
        pass

    def test_doi_prefix_suffix_reports_get(self) -> None:
        """Test case for doi_prefix_suffix_reports_get

        Returns the list of the experimental reports coming from the user portal and information needed for the display
        """
        pass

    def test_doi_session_id_mint_post(self) -> None:
        """Test case for doi_session_id_mint_post

        It mints a DOI
        """
        pass

    def test_doi_session_id_reserve_post(self) -> None:
        """Test case for doi_session_id_reserve_post

        It reserves a DOI
        """
        pass

    def test_doi_session_id_reserved_dois_get(self) -> None:
        """Test case for doi_session_id_reserved_dois_get

        Returns the list of reserved DOIs for a given user
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.data_acquisition_api import DataAcquisitionApi


class TestDataAcquisitionApi(unittest.TestCase):
    """DataAcquisitionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataAcquisitionApi()

    def tearDown(self) -> None:
        pass

    def test_dataacquisition_api_key_base64_post(self) -> None:
        """Test case for dataacquisition_api_key_base64_post

        Uploads an image in base64 format to the investigation electronic logbook
        """
        pass

    def test_dataacquisition_api_key_dataset_get(self) -> None:
        """Test case for dataacquisition_api_key_dataset_get

        Gets datasets
        """
        pass

    def test_dataacquisition_api_key_dataset_restore_post(self) -> None:
        """Test case for dataacquisition_api_key_dataset_restore_post

        Update the restore status of a dataset access and send an email to the users who asked for the restoration
        """
        pass

    def test_dataacquisition_api_key_events_move_post(self) -> None:
        """Test case for dataacquisition_api_key_events_move_post

        move the events from one investigation to another
        """
        pass

    def test_dataacquisition_api_key_investigation_get(self) -> None:
        """Test case for dataacquisition_api_key_investigation_get

        Get investigations
        """
        pass

    def test_dataacquisition_api_key_mint_post(self) -> None:
        """Test case for dataacquisition_api_key_mint_post

        It mints a DOI
        """
        pass

    def test_dataacquisition_api_key_notification_post(self) -> None:
        """Test case for dataacquisition_api_key_notification_post

        Adds an event to the logbook (for an investigation or beamline logbook). It could also be a machine event
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.sampleinformation import Sampleinformation

class TestSampleinformation(unittest.TestCase):
    """Sampleinformation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Sampleinformation:
        """Test Sampleinformation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Sampleinformation`
        """
        model = Sampleinformation()
        if include_optional:
            return Sampleinformation(
                id = '',
                investigation_id = 56,
                sample_id = 56,
                resources = [
                    icat_plus_client.models.resourceinformation.resourceinformation(
                        _id = '', 
                        filename = '', 
                        file_type = '', 
                        group_name = '', 
                        multiplicity = 1.337, 
                        file = '', )
                    ]
            )
        else:
            return Sampleinformation(
                id = '',
                investigation_id = 56,
                sample_id = 56,
        )
        """

    def testSampleinformation(self):
        """Test Sampleinformation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.ids_api import IDSApi


class TestIDSApi(unittest.TestCase):
    """IDSApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IDSApi()

    def tearDown(self) -> None:
        pass

    def test_ids_session_id_data_download_get(self) -> None:
        """Test case for ids_session_id_data_download_get

        Redirects to IDS server to download datasets or datafiles
        """
        pass

    def test_ids_session_id_datasets_restore_post(self) -> None:
        """Test case for ids_session_id_datasets_restore_post

        Records dataset restoration request by a user and redirects to IDS server to download datasets or datafiles
        """
        pass

    def test_ids_session_id_datasets_status_get(self) -> None:
        """Test case for ids_session_id_datasets_status_get

        Return the IDS status of the datasets specified by the datasetIds along with a sessionId.
        """
        pass

    def test_ids_session_id_path_get(self) -> None:
        """Test case for ids_session_id_path_get

        Returns the location of the files or datasets
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from icat_plus_client.api.actions_api import ActionsApi
from icat_plus_client.api.cache_api import CacheApi
from icat_plus_client.api.catalogue_api import CatalogueApi
from icat_plus_client.api.dmp_api import DMPApi
from icat_plus_client.api.doi_api import DOIApi
from icat_plus_client.api.data_acquisition_api import DataAcquisitionApi
from icat_plus_client.api.ewoks_api import EWOKSApi
from icat_plus_client.api.elastic_search_api import ElasticSearchApi
from icat_plus_client.api.h5_grove_api import H5GroveApi
from icat_plus_client.api.ids_api import IDSApi
from icat_plus_client.api.logbook_api import LogbookApi
from icat_plus_client.api.messages_api import MESSAGESApi
from icat_plus_client.api.oaipmh_api import OAIPMHApi
from icat_plus_client.api.panosc_api import PanoscApi
from icat_plus_client.api.resource_api import ResourceApi
from icat_plus_client.api.sample_metadata_api import SampleMetadataApi
from icat_plus_client.api.session_api import SessionApi
from icat_plus_client.api.tracking_api import TrackingApi
from icat_plus_client.api.users_api import USERSApi
from icat_plus_client.api.user_management_api import UserManagementApi

# import ApiClient
from icat_plus_client.api_response import ApiResponse
from icat_plus_client.api_client import ApiClient
from icat_plus_client.configuration import Configuration
from icat_plus_client.exceptions import OpenApiException
from icat_plus_client.exceptions import ApiTypeError
from icat_plus_client.exceptions import ApiValueError
from icat_plus_client.exceptions import ApiKeyError
from icat_plus_client.exceptions import ApiAttributeError
from icat_plus_client.exceptions import ApiException

# import models into sdk package
from icat_plus_client.icat_plus_client.model.actions import Actions
from icat_plus_client.icat_plus_client.model.address import Address
from icat_plus_client.icat_plus_client.model.authors_inner import AuthorsInner
from icat_plus_client.icat_plus_client.model.cache_stats import CacheStats
from icat_plus_client.icat_plus_client.model.cache_user_storage import CacheUserStorage
from icat_plus_client.icat_plus_client.model.catalogue_session_id_instrumentscientist_delete_request import CatalogueSessionIdInstrumentscientistDeleteRequest
from icat_plus_client.icat_plus_client.model.catalogue_session_id_instrumentscientist_put_request import CatalogueSessionIdInstrumentscientistPutRequest
from icat_plus_client.icat_plus_client.model.catalogue_session_id_investigation_id_investigation_id_investigationusers_post_request import CatalogueSessionIdInvestigationIdInvestigationIdInvestigationusersPostRequest
from icat_plus_client.icat_plus_client.model.credentials import Credentials
from icat_plus_client.icat_plus_client.model.dataacquisition_api_key_base64_post_request import DataacquisitionApiKeyBase64PostRequest
from icat_plus_client.icat_plus_client.model.dataacquisition_api_key_dataset_restore_post_request import DataacquisitionApiKeyDatasetRestorePostRequest
from icat_plus_client.icat_plus_client.model.dataacquisition_api_key_mint_post200_response import DataacquisitionApiKeyMintPost200Response
from icat_plus_client.icat_plus_client.model.dataacquisition_api_key_mint_post_request import DataacquisitionApiKeyMintPostRequest
from icat_plus_client.icat_plus_client.model.datacollection import Datacollection
from icat_plus_client.icat_plus_client.model.datacollection_data_collection_datasets_inner import DatacollectionDataCollectionDatasetsInner
from icat_plus_client.icat_plus_client.model.datacollection_data_collection_datasets_inner_dataset import DatacollectionDataCollectionDatasetsInnerDataset
from icat_plus_client.icat_plus_client.model.datafile import Datafile
from icat_plus_client.icat_plus_client.model.datafilelight import Datafilelight
from icat_plus_client.icat_plus_client.model.dataset import Dataset
from icat_plus_client.icat_plus_client.model.dataset_document import DatasetDocument
from icat_plus_client.icat_plus_client.model.dataset_document_investigation import DatasetDocumentInvestigation
from icat_plus_client.icat_plus_client.model.dataset_document_parameters_inner import DatasetDocumentParametersInner
from icat_plus_client.icat_plus_client.model.dataset_techniques_inner import DatasetTechniquesInner
from icat_plus_client.icat_plus_client.model.datasetaccess import Datasetaccess
from icat_plus_client.icat_plus_client.model.datasetparameter import Datasetparameter
from icat_plus_client.icat_plus_client.model.dmpquestionnaire import Dmpquestionnaire
from icat_plus_client.icat_plus_client.model.doi_data import DoiData
from icat_plus_client.icat_plus_client.model.doi_session_id_mint_post_request import DoiSessionIdMintPostRequest
from icat_plus_client.icat_plus_client.model.doi_session_id_reserve_post_request import DoiSessionIdReservePostRequest
from icat_plus_client.icat_plus_client.model.elasticsearch_session_id_stats_instrument_metrics_get_request_inner import ElasticsearchSessionIdStatsInstrumentMetricsGetRequestInner
from icat_plus_client.icat_plus_client.model.event import Event
from icat_plus_client.icat_plus_client.model.event_content_inner import EventContentInner
from icat_plus_client.icat_plus_client.model.ewoks_session_id_jobs_post_request import EwoksSessionIdJobsPostRequest
from icat_plus_client.icat_plus_client.model.ewoks_session_id_jobs_put_request import EwoksSessionIdJobsPutRequest
from icat_plus_client.icat_plus_client.model.ewoks_session_id_jobs_put_request_step import EwoksSessionIdJobsPutRequestStep
from icat_plus_client.icat_plus_client.model.expreports_inner import ExpreportsInner
from icat_plus_client.icat_plus_client.model.ids_session_id_datasets_restore_post_request import IdsSessionIdDatasetsRestorePostRequest
from icat_plus_client.icat_plus_client.model.instrument import Instrument
from icat_plus_client.icat_plus_client.model.instrumentscientist import Instrumentscientist
from icat_plus_client.icat_plus_client.model.instrumentscientist_instrument import InstrumentscientistInstrument
from icat_plus_client.icat_plus_client.model.instrumentscientist_mod import InstrumentscientistMod
from icat_plus_client.icat_plus_client.model.instrumentscientist_user import InstrumentscientistUser
from icat_plus_client.icat_plus_client.model.investigation import Investigation
from icat_plus_client.icat_plus_client.model.investigation_instrument import InvestigationInstrument
from icat_plus_client.icat_plus_client.model.investigation_investigation_users_inner import InvestigationInvestigationUsersInner
from icat_plus_client.icat_plus_client.model.investigation_investigation_users_inner_user import InvestigationInvestigationUsersInnerUser
from icat_plus_client.icat_plus_client.model.investigation_type import InvestigationType
from icat_plus_client.icat_plus_client.model.investigationlight import Investigationlight
from icat_plus_client.icat_plus_client.model.investigationusers import Investigationusers
from icat_plus_client.icat_plus_client.model.item import Item
from icat_plus_client.icat_plus_client.model.job import Job
from icat_plus_client.icat_plus_client.model.job_investigations_inner import JobInvestigationsInner
from icat_plus_client.icat_plus_client.model.json_datacite import JsonDatacite
from icat_plus_client.icat_plus_client.model.json_datacite_dates_inner import JsonDataciteDatesInner
from icat_plus_client.icat_plus_client.model.json_datacite_subjects_inner import JsonDataciteSubjectsInner
from icat_plus_client.icat_plus_client.model.json_datacite_titles import JsonDataciteTitles
from icat_plus_client.icat_plus_client.model.logbook_filters import LogbookFilters
from icat_plus_client.icat_plus_client.model.logbook_investigation_stat import LogbookInvestigationStat
from icat_plus_client.icat_plus_client.model.logbook_investigation_stat_count import LogbookInvestigationStatCount
from icat_plus_client.icat_plus_client.model.logbook_session_id_event_createfrombase64_post_request import LogbookSessionIdEventCreatefrombase64PostRequest
from icat_plus_client.icat_plus_client.model.logbook_session_id_event_put_request import LogbookSessionIdEventPutRequest
from icat_plus_client.icat_plus_client.model.logbook_session_id_event_put_request_event import LogbookSessionIdEventPutRequestEvent
from icat_plus_client.icat_plus_client.model.logbook_session_id_events_patch_request import LogbookSessionIdEventsPatchRequest
from icat_plus_client.icat_plus_client.model.member import Member
from icat_plus_client.icat_plus_client.model.message import Message
from icat_plus_client.icat_plus_client.model.meta import Meta
from icat_plus_client.icat_plus_client.model.meta_page import MetaPage
from icat_plus_client.icat_plus_client.model.modified_object import ModifiedObject
from icat_plus_client.icat_plus_client.model.mxcutoffs import Mxcutoffs
from icat_plus_client.icat_plus_client.model.mxsettings import Mxsettings
from icat_plus_client.icat_plus_client.model.mxshell import Mxshell
from icat_plus_client.icat_plus_client.model.pagination_inner import PaginationInner
from icat_plus_client.icat_plus_client.model.parameter import Parameter
from icat_plus_client.icat_plus_client.model.parcel import Parcel
from icat_plus_client.icat_plus_client.model.parcel_status import ParcelStatus
from icat_plus_client.icat_plus_client.model.recently_visited import RecentlyVisited
from icat_plus_client.icat_plus_client.model.relateditem import Relateditem
from icat_plus_client.icat_plus_client.model.resourceinformation import Resourceinformation
from icat_plus_client.icat_plus_client.model.return_parcel_information import ReturnParcelInformation
from icat_plus_client.icat_plus_client.model.sample import Sample
from icat_plus_client.icat_plus_client.model.sample_datasets_inner import SampleDatasetsInner
from icat_plus_client.icat_plus_client.model.sample_datasets_inner_parameters_inner import SampleDatasetsInnerParametersInner
from icat_plus_client.icat_plus_client.model.sample_investigation import SampleInvestigation
from icat_plus_client.icat_plus_client.model.sample_investigation_instrument import SampleInvestigationInstrument
from icat_plus_client.icat_plus_client.model.sampleinformation import Sampleinformation
from icat_plus_client.icat_plus_client.model.samplemetadata import Samplemetadata
from icat_plus_client.icat_plus_client.model.samplemetadata_session_id_samples_delete200_response import SamplemetadataSessionIdSamplesDelete200Response
from icat_plus_client.icat_plus_client.model.samplemetadatasample import Samplemetadatasample
from icat_plus_client.icat_plus_client.model.samplemetadatasimplifiedsample import Samplemetadatasimplifiedsample
from icat_plus_client.icat_plus_client.model.session import Session
from icat_plus_client.icat_plus_client.model.session_session_id_get200_response import SessionSessionIdGet200Response
from icat_plus_client.icat_plus_client.model.setup import Setup
from icat_plus_client.icat_plus_client.model.shipment import Shipment
from icat_plus_client.icat_plus_client.model.status import Status
from icat_plus_client.icat_plus_client.model.tag import Tag
from icat_plus_client.icat_plus_client.model.target import Target
from icat_plus_client.icat_plus_client.model.technique import Technique
from icat_plus_client.icat_plus_client.model.timeline import Timeline
from icat_plus_client.icat_plus_client.model.tracking import Tracking
from icat_plus_client.icat_plus_client.model.tracking_information import TrackingInformation
from icat_plus_client.icat_plus_client.model.user import User
from icat_plus_client.icat_plus_client.model.userpreferences import Userpreferences
from icat_plus_client.icat_plus_client.model.userpreferences_selection import UserpreferencesSelection



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.shipment import Shipment

class TestShipment(unittest.TestCase):
    """Shipment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Shipment:
        """Test Shipment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Shipment`
        """
        model = Shipment()
        if include_optional:
            return Shipment(
                id = '',
                investigation_id = 56,
                investigation_name = '',
                name = '',
                default_return_address = icat_plus_client.models.address.address(
                    _id = '', 
                    name = '', 
                    surname = '', 
                    company_name = '', 
                    address = '', 
                    city = '', 
                    region = '', 
                    postal_code = '', 
                    country = '', 
                    email = '', 
                    phone_number = '', 
                    default_courier_account = '', 
                    default_courier_company = '', ),
                default_shipping_address = icat_plus_client.models.address.address(
                    _id = '', 
                    name = '', 
                    surname = '', 
                    company_name = '', 
                    address = '', 
                    city = '', 
                    region = '', 
                    postal_code = '', 
                    country = '', 
                    email = '', 
                    phone_number = '', 
                    default_courier_account = '', 
                    default_courier_company = '', ),
                parcels = [
                    icat_plus_client.models.parcel.parcel(
                        _id = '', 
                        shipment_id = '', 
                        name = '', 
                        investigation_id = 1.337, 
                        investigation_name = '', 
                        storage_conditions = '', 
                        is_reimbursed = True, 
                        reimbursed_customs_value = 1.337, 
                        return_instructions = '', 
                        return_parcel_information = icat_plus_client.models.return_parcel_information.returnParcelInformation(
                            _id = '', 
                            return_type = 'USER_MANAGE_PAPERS', 
                            forwarder_name = '', 
                            forwarder_account = '', 
                            planned_pickup_date = '', ), 
                        comments = '', 
                        contains_dangerous_goods = True, 
                        statuses = [
                            icat_plus_client.models.status.status(
                                _id = '', 
                                status = '', 
                                created_by = '', 
                                created_at = '', 
                                updated_at = '', 
                                created_by_full_name = '', 
                                created_by_email = '', )
                            ], 
                        shipping_address = icat_plus_client.models.address.address(
                            _id = '', 
                            name = '', 
                            surname = '', 
                            company_name = '', 
                            address = '', 
                            city = '', 
                            region = '', 
                            postal_code = '', 
                            country = '', 
                            email = '', 
                            phone_number = '', 
                            default_courier_account = '', 
                            default_courier_company = '', ), 
                        return_address = icat_plus_client.models.address.address(
                            _id = '', 
                            name = '', 
                            surname = '', 
                            company_name = '', 
                            city = '', 
                            region = '', 
                            postal_code = '', 
                            country = '', 
                            email = '', 
                            phone_number = '', 
                            default_courier_account = '', 
                            default_courier_company = '', ), 
                        shipping_tracking_information = icat_plus_client.models.tracking_information.trackingInformation(
                            _id = '', 
                            tracking_number = '', 
                            forwarder = '', ), 
                        return_tracking_information = icat_plus_client.models.tracking_information.trackingInformation(
                            _id = '', 
                            tracking_number = '', 
                            forwarder = '', ), 
                        description = '', 
                        type = '', 
                        current_status = '', 
                        items = [
                            icat_plus_client.models.item.item(
                                id = '', 
                                name = '', 
                                type = '', 
                                description = '', 
                                comments = '', )
                            ], 
                        local_contact_names = [
                            ''
                            ], 
                        content = [
                            icat_plus_client.models.item.item(
                                id = '', 
                                name = '', 
                                type = '', 
                                description = '', 
                                comments = '', )
                            ], 
                        created_at = '', 
                        updated_at = '', 
                        id = '', 
                        investigation = icat_plus_client.models.investigation.investigation(
                            id = 1.337, 
                            name = '', 
                            start_date = '', 
                            end_date = '', 
                            doi = '', 
                            title = '', 
                            visit_id = '', 
                            release_date = '', 
                            summary = '', 
                            parameters = icat_plus_client.models.parameters.parameters(), 
                            instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                                id = 1.337, 
                                name = '', 
                                instrument_scientists = [
                                    icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                        name = '', )
                                    ], ), 
                            investigation_users = [
                                icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                                    role = '', 
                                    user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                        email = '', 
                                        full_name = '', 
                                        family_name = '', 
                                        name = '', 
                                        given_name = '', ), )
                                ], 
                            meta = icat_plus_client.models.meta.meta(
                                page = icat_plus_client.models.meta_page.meta_page(
                                    total = 1.337, 
                                    total_pages = 1.337, 
                                    current_page = 1.337, ), ), 
                            type = icat_plus_client.models.investigation_type.investigation_type(
                                id = 1.337, 
                                create_id = '', 
                                create_time = '', 
                                mod_id = '', 
                                mod_time = '', 
                                description = '', 
                                name = '', ), 
                            can_access_datasets = True, ), 
                        meta = icat_plus_client.models.meta.meta(), )
                    ]
            )
        else:
            return Shipment(
                investigation_name = '',
                name = '',
        )
        """

    def testShipment(self):
        """Test Shipment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.investigation_investigation_users_inner import InvestigationInvestigationUsersInner

class TestInvestigationInvestigationUsersInner(unittest.TestCase):
    """InvestigationInvestigationUsersInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvestigationInvestigationUsersInner:
        """Test InvestigationInvestigationUsersInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvestigationInvestigationUsersInner`
        """
        model = InvestigationInvestigationUsersInner()
        if include_optional:
            return InvestigationInvestigationUsersInner(
                role = '',
                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                    email = '', 
                    full_name = '', 
                    family_name = '', 
                    name = '', 
                    given_name = '', )
            )
        else:
            return InvestigationInvestigationUsersInner(
                role = '',
                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                    email = '', 
                    full_name = '', 
                    family_name = '', 
                    name = '', 
                    given_name = '', ),
        )
        """

    def testInvestigationInvestigationUsersInner(self):
        """Test InvestigationInvestigationUsersInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.json_datacite_dates_inner import JsonDataciteDatesInner

class TestJsonDataciteDatesInner(unittest.TestCase):
    """JsonDataciteDatesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonDataciteDatesInner:
        """Test JsonDataciteDatesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonDataciteDatesInner`
        """
        model = JsonDataciteDatesInner()
        if include_optional:
            return JsonDataciteDatesInner(
                var_date = '',
                date_type = ''
            )
        else:
            return JsonDataciteDatesInner(
        )
        """

    def testJsonDataciteDatesInner(self):
        """Test JsonDataciteDatesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.json_datacite import JsonDatacite

class TestJsonDatacite(unittest.TestCase):
    """JsonDatacite unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonDatacite:
        """Test JsonDatacite
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonDatacite`
        """
        model = JsonDatacite()
        if include_optional:
            return JsonDatacite(
                doi = '',
                url = '',
                publication_year = '',
                creators = [
                    icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                        name = '', )
                    ],
                titles = icat_plus_client.models.json_datacite_titles.json_datacite_titles(
                    title = '', ),
                publisher = '',
                subjects = [
                    icat_plus_client.models.json_datacite_subjects_inner.json_datacite_subjects_inner(
                        subject_scheme = '', )
                    ],
                dates = [
                    icat_plus_client.models.json_datacite_dates_inner.json_datacite_dates_inner(
                        date = '', 
                        date_type = '', )
                    ]
            )
        else:
            return JsonDatacite(
                doi = '',
                url = '',
                publication_year = '',
                creators = [
                    icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                        name = '', )
                    ],
                titles = icat_plus_client.models.json_datacite_titles.json_datacite_titles(
                    title = '', ),
                publisher = '',
                subjects = [
                    icat_plus_client.models.json_datacite_subjects_inner.json_datacite_subjects_inner(
                        subject_scheme = '', )
                    ],
                dates = [
                    icat_plus_client.models.json_datacite_dates_inner.json_datacite_dates_inner(
                        date = '', 
                        date_type = '', )
                    ],
        )
        """

    def testJsonDatacite(self):
        """Test JsonDatacite"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.session_api import SessionApi


class TestSessionApi(unittest.TestCase):
    """SessionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SessionApi()

    def tearDown(self) -> None:
        pass

    def test_session_post(self) -> None:
        """Test case for session_post

        This is used to log into the app
        """
        pass

    def test_session_session_id_delete(self) -> None:
        """Test case for session_session_id_delete

        Log out
        """
        pass

    def test_session_session_id_get(self) -> None:
        """Test case for session_session_id_get

        Gets information about the session in ICAT
        """
        pass

    def test_session_session_id_put(self) -> None:
        """Test case for session_session_id_put

        This is used to refresh the current session. It returns code 204 if refreshed
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.event import Event

class TestEvent(unittest.TestCase):
    """Event unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Event:
        """Test Event
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Event`
        """
        model = Event()
        if include_optional:
            return Event(
                id = 56,
                investigation_id = 56,
                investigation_name = '',
                instrument_name = '',
                dataset_id = 56,
                type = 'notification',
                tag = [
                    icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                        name = '', )
                    ],
                title = '',
                category = 'commandline',
                filepath = '',
                filename = '',
                file_size = '',
                username = '',
                content = [
                    icat_plus_client.models.event_content_inner.event_content_inner(
                        format = '', 
                        text = '', )
                    ],
                software = '',
                machine = '',
                source = '',
                creation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                content_type = '',
                file = '',
                previous_version_event = None
            )
        else:
            return Event(
                investigation_id = 56,
                type = 'notification',
                category = 'commandline',
        )
        """

    def testEvent(self):
        """Test Event"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.ewoks_api import EWOKSApi


class TestEWOKSApi(unittest.TestCase):
    """EWOKSApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EWOKSApi()

    def tearDown(self) -> None:
        pass

    def test_ewoks_session_id_jobs_get(self) -> None:
        """Test case for ewoks_session_id_jobs_get

        Returns a list of the jobs
        """
        pass

    def test_ewoks_session_id_jobs_post(self) -> None:
        """Test case for ewoks_session_id_jobs_post

        Launch a job
        """
        pass

    def test_ewoks_session_id_jobs_put(self) -> None:
        """Test case for ewoks_session_id_jobs_put

        updates a job
        """
        pass

    def test_ewoks_session_id_workflows_get(self) -> None:
        """Test case for ewoks_session_id_workflows_get

        Returns a list with the content of the graph of each workflow
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.logbook_api import LogbookApi


class TestLogbookApi(unittest.TestCase):
    """LogbookApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LogbookApi()

    def tearDown(self) -> None:
        pass

    def test_logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_createfrombase64_post(self) -> None:
        """Test case for logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_createfrombase64_post

        Create an event given a base64 string. It requires the API token. This is used on the spec beamlines from the metadata manager
        """
        pass

    def test_logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_post(self) -> None:
        """Test case for logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_post

        This is used on the spec beamlines from the metadata manager
        """
        pass

    def test_logbook_session_id_event_count_get(self) -> None:
        """Test case for logbook_session_id_event_count_get

        Count events
        """
        pass

    def test_logbook_session_id_event_createfrombase64_post(self) -> None:
        """Test case for logbook_session_id_event_createfrombase64_post

        Create an event given a base64 string
        """
        pass

    def test_logbook_session_id_event_dates_get(self) -> None:
        """Test case for logbook_session_id_event_dates_get

        Lists events dates
        """
        pass

    def test_logbook_session_id_event_get(self) -> None:
        """Test case for logbook_session_id_event_get

        Lists events
        """
        pass

    def test_logbook_session_id_event_page_get(self) -> None:
        """Test case for logbook_session_id_event_page_get

        Gets the number of page where the event is
        """
        pass

    def test_logbook_session_id_event_post(self) -> None:
        """Test case for logbook_session_id_event_post

        Creates an event
        """
        pass

    def test_logbook_session_id_event_put(self) -> None:
        """Test case for logbook_session_id_event_put

        Updates an event
        """
        pass

    def test_logbook_session_id_event_remove_put(self) -> None:
        """Test case for logbook_session_id_event_remove_put

        Flag events as removed
        """
        pass

    def test_logbook_session_id_event_restore_put(self) -> None:
        """Test case for logbook_session_id_event_restore_put

        Flag events as restored by setting removed = false for each event. InvestigationId is mandatory
        """
        pass

    def test_logbook_session_id_events_patch(self) -> None:
        """Test case for logbook_session_id_events_patch

        Updates the tags of a list of events
        """
        pass

    def test_logbook_session_id_stats_count_get(self) -> None:
        """Test case for logbook_session_id_stats_count_get

        Counts number of event for date range
        """
        pass

    def test_logbook_session_id_stats_investigation_get(self) -> None:
        """Test case for logbook_session_id_stats_investigation_get

        Lists statistics on events for each investigation that are allocated in the date range
        """
        pass

    def test_logbook_session_id_tag_get(self) -> None:
        """Test case for logbook_session_id_tag_get

        GET all tags available, (ie used in the investigation or not) for a given logbook including global, beamline specific and investigation specific tags. Tags available but not used are also retrieved.
        """
        pass

    def test_logbook_session_id_tag_post(self) -> None:
        """Test case for logbook_session_id_tag_post

        Create an investigation tag for a given investigationId
        """
        pass

    def test_logbook_session_id_tag_put(self) -> None:
        """Test case for logbook_session_id_tag_put

        Update an investigation tag
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.investigation import Investigation

class TestInvestigation(unittest.TestCase):
    """Investigation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Investigation:
        """Test Investigation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Investigation`
        """
        model = Investigation()
        if include_optional:
            return Investigation(
                id = 1.337,
                name = '',
                start_date = '',
                end_date = '',
                doi = '',
                title = '',
                visit_id = '',
                release_date = '',
                summary = '',
                parameters = icat_plus_client.models.parameters.parameters(),
                instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                    id = 1.337, 
                    name = '', 
                    instrument_scientists = [
                        icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                            name = '', )
                        ], ),
                investigation_users = [
                    icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                        role = '', 
                        user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                            email = '', 
                            full_name = '', 
                            family_name = '', 
                            name = '', 
                            given_name = '', ), )
                    ],
                meta = icat_plus_client.models.meta.meta(
                    page = icat_plus_client.models.meta_page.meta_page(
                        total = 1.337, 
                        total_pages = 1.337, 
                        current_page = 1.337, ), ),
                type = icat_plus_client.models.investigation_type.investigation_type(
                    id = 1.337, 
                    create_id = '', 
                    create_time = '', 
                    mod_id = '', 
                    mod_time = '', 
                    description = '', 
                    name = '', ),
                can_access_datasets = True
            )
        else:
            return Investigation(
                id = 1.337,
                name = '',
                start_date = '',
        )
        """

    def testInvestigation(self):
        """Test Investigation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.elastic_search_api import ElasticSearchApi


class TestElasticSearchApi(unittest.TestCase):
    """ElasticSearchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ElasticSearchApi()

    def tearDown(self) -> None:
        pass

    def test_elasticsearch_session_id_datasets_msearch_get(self) -> None:
        """Test case for elasticsearch_session_id_datasets_msearch_get

        Proxy to elastic search server
        """
        pass

    def test_elasticsearch_session_id_stats_histogram_get(self) -> None:
        """Test case for elasticsearch_session_id_stats_histogram_get

        Gets time series statistics. Only administrator and instrumentScientists are allowed
        """
        pass

    def test_elasticsearch_session_id_stats_instrument_metrics_get(self) -> None:
        """Test case for elasticsearch_session_id_stats_instrument_metrics_get

        Given an array of dates it returns the statistics for each instrument
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.sample import Sample

class TestSample(unittest.TestCase):
    """Sample unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Sample:
        """Test Sample
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Sample`
        """
        model = Sample()
        if include_optional:
            return Sample(
                id = 1.337,
                name = '',
                mod_time = '',
                investigation = icat_plus_client.models.sample_investigation.sample_investigation(
                    id = 1.337, 
                    name = '', 
                    start_date = '', 
                    end_date = '', 
                    title = '', 
                    visit_id = '', 
                    instrument = icat_plus_client.models.sample_investigation_instrument.sample_investigation_instrument(
                        id = 1.337, 
                        name = '', ), ),
                datasets = [
                    icat_plus_client.models.sample_datasets_inner.sample_datasets_inner(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        location = '', 
                        type = '', 
                        parameters = [
                            icat_plus_client.models.sample_datasets_inner_parameters_inner.sample_datasets_inner_parameters_inner(
                                id = 1.337, 
                                name = '', 
                                value = '', 
                                units = '', )
                            ], )
                    ],
                parameters = [
                    icat_plus_client.models.sample_datasets_inner_parameters_inner.sample_datasets_inner_parameters_inner(
                        id = 1.337, 
                        name = '', 
                        value = '', 
                        units = '', )
                    ],
                meta = icat_plus_client.models.meta.meta(
                    page = icat_plus_client.models.meta_page.meta_page(
                        total = 1.337, 
                        total_pages = 1.337, 
                        current_page = 1.337, ), )
            )
        else:
            return Sample(
                id = 1.337,
                name = '',
        )
        """

    def testSample(self):
        """Test Sample"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.cache_user_storage import CacheUserStorage

class TestCacheUserStorage(unittest.TestCase):
    """CacheUserStorage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CacheUserStorage:
        """Test CacheUserStorage
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CacheUserStorage`
        """
        model = CacheUserStorage()
        if include_optional:
            return CacheUserStorage(
                username = '',
                my_investigations = [
                    icat_plus_client.models.investigation.investigation(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        doi = '', 
                        title = '', 
                        visit_id = '', 
                        release_date = '', 
                        summary = '', 
                        parameters = icat_plus_client.models.parameters.parameters(), 
                        instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                            id = 1.337, 
                            name = '', 
                            instrument_scientists = [
                                icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                    name = '', )
                                ], ), 
                        investigation_users = [
                            icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                                role = '', 
                                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                    email = '', 
                                    full_name = '', 
                                    family_name = '', 
                                    name = '', 
                                    given_name = '', ), )
                            ], 
                        meta = icat_plus_client.models.meta.meta(
                            page = icat_plus_client.models.meta_page.meta_page(
                                total = 1.337, 
                                total_pages = 1.337, 
                                current_page = 1.337, ), ), 
                        type = icat_plus_client.models.investigation_type.investigation_type(
                            id = 1.337, 
                            create_id = '', 
                            create_time = '', 
                            mod_id = '', 
                            mod_time = '', 
                            description = '', 
                            name = '', ), 
                        can_access_datasets = True, )
                    ],
                investigations = [
                    icat_plus_client.models.investigation.investigation(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        doi = '', 
                        title = '', 
                        visit_id = '', 
                        release_date = '', 
                        summary = '', 
                        parameters = icat_plus_client.models.parameters.parameters(), 
                        instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                            id = 1.337, 
                            name = '', 
                            instrument_scientists = [
                                icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                    name = '', )
                                ], ), 
                        investigation_users = [
                            icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                                role = '', 
                                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                    email = '', 
                                    full_name = '', 
                                    family_name = '', 
                                    name = '', 
                                    given_name = '', ), )
                            ], 
                        meta = icat_plus_client.models.meta.meta(
                            page = icat_plus_client.models.meta_page.meta_page(
                                total = 1.337, 
                                total_pages = 1.337, 
                                current_page = 1.337, ), ), 
                        type = icat_plus_client.models.investigation_type.investigation_type(
                            id = 1.337, 
                            create_id = '', 
                            create_time = '', 
                            mod_id = '', 
                            mod_time = '', 
                            description = '', 
                            name = '', ), 
                        can_access_datasets = True, )
                    ],
                investigations_id = [
                    icat_plus_client.models.investigation.investigation(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        doi = '', 
                        title = '', 
                        visit_id = '', 
                        release_date = '', 
                        summary = '', 
                        parameters = icat_plus_client.models.parameters.parameters(), 
                        instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                            id = 1.337, 
                            name = '', 
                            instrument_scientists = [
                                icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                    name = '', )
                                ], ), 
                        investigation_users = [
                            icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                                role = '', 
                                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                    email = '', 
                                    full_name = '', 
                                    family_name = '', 
                                    name = '', 
                                    given_name = '', ), )
                            ], 
                        meta = icat_plus_client.models.meta.meta(
                            page = icat_plus_client.models.meta_page.meta_page(
                                total = 1.337, 
                                total_pages = 1.337, 
                                current_page = 1.337, ), ), 
                        type = icat_plus_client.models.investigation_type.investigation_type(
                            id = 1.337, 
                            create_id = '', 
                            create_time = '', 
                            mod_id = '', 
                            mod_time = '', 
                            description = '', 
                            name = '', ), 
                        can_access_datasets = True, )
                    ]
            )
        else:
            return CacheUserStorage(
                username = '',
                my_investigations = [
                    icat_plus_client.models.investigation.investigation(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        doi = '', 
                        title = '', 
                        visit_id = '', 
                        release_date = '', 
                        summary = '', 
                        parameters = icat_plus_client.models.parameters.parameters(), 
                        instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                            id = 1.337, 
                            name = '', 
                            instrument_scientists = [
                                icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                    name = '', )
                                ], ), 
                        investigation_users = [
                            icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                                role = '', 
                                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                    email = '', 
                                    full_name = '', 
                                    family_name = '', 
                                    name = '', 
                                    given_name = '', ), )
                            ], 
                        meta = icat_plus_client.models.meta.meta(
                            page = icat_plus_client.models.meta_page.meta_page(
                                total = 1.337, 
                                total_pages = 1.337, 
                                current_page = 1.337, ), ), 
                        type = icat_plus_client.models.investigation_type.investigation_type(
                            id = 1.337, 
                            create_id = '', 
                            create_time = '', 
                            mod_id = '', 
                            mod_time = '', 
                            description = '', 
                            name = '', ), 
                        can_access_datasets = True, )
                    ],
                investigations = [
                    icat_plus_client.models.investigation.investigation(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        doi = '', 
                        title = '', 
                        visit_id = '', 
                        release_date = '', 
                        summary = '', 
                        parameters = icat_plus_client.models.parameters.parameters(), 
                        instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                            id = 1.337, 
                            name = '', 
                            instrument_scientists = [
                                icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                    name = '', )
                                ], ), 
                        investigation_users = [
                            icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                                role = '', 
                                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                    email = '', 
                                    full_name = '', 
                                    family_name = '', 
                                    name = '', 
                                    given_name = '', ), )
                            ], 
                        meta = icat_plus_client.models.meta.meta(
                            page = icat_plus_client.models.meta_page.meta_page(
                                total = 1.337, 
                                total_pages = 1.337, 
                                current_page = 1.337, ), ), 
                        type = icat_plus_client.models.investigation_type.investigation_type(
                            id = 1.337, 
                            create_id = '', 
                            create_time = '', 
                            mod_id = '', 
                            mod_time = '', 
                            description = '', 
                            name = '', ), 
                        can_access_datasets = True, )
                    ],
                investigations_id = [
                    icat_plus_client.models.investigation.investigation(
                        id = 1.337, 
                        name = '', 
                        start_date = '', 
                        end_date = '', 
                        doi = '', 
                        title = '', 
                        visit_id = '', 
                        release_date = '', 
                        summary = '', 
                        parameters = icat_plus_client.models.parameters.parameters(), 
                        instrument = icat_plus_client.models.investigation_instrument.investigation_instrument(
                            id = 1.337, 
                            name = '', 
                            instrument_scientists = [
                                icat_plus_client.models._ewoks__session_id__jobs_post_request._ewoks__sessionId__jobs_post_request(
                                    name = '', )
                                ], ), 
                        investigation_users = [
                            icat_plus_client.models.investigation_investigation_users_inner.investigation_investigationUsers_inner(
                                role = '', 
                                user = icat_plus_client.models.investigation_investigation_users_inner_user.investigation_investigationUsers_inner_user(
                                    email = '', 
                                    full_name = '', 
                                    family_name = '', 
                                    name = '', 
                                    given_name = '', ), )
                            ], 
                        meta = icat_plus_client.models.meta.meta(
                            page = icat_plus_client.models.meta_page.meta_page(
                                total = 1.337, 
                                total_pages = 1.337, 
                                current_page = 1.337, ), ), 
                        type = icat_plus_client.models.investigation_type.investigation_type(
                            id = 1.337, 
                            create_id = '', 
                            create_time = '', 
                            mod_id = '', 
                            mod_time = '', 
                            description = '', 
                            name = '', ), 
                        can_access_datasets = True, )
                    ],
        )
        """

    def testCacheUserStorage(self):
        """Test CacheUserStorage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.tracking import Tracking

class TestTracking(unittest.TestCase):
    """Tracking unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Tracking:
        """Test Tracking
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Tracking`
        """
        model = Tracking()
        if include_optional:
            return Tracking(
                id = '',
                tracking_id = '',
                address = icat_plus_client.models.address.address(
                    _id = '', 
                    name = '', 
                    surname = '', 
                    company_name = '', 
                    address = '', 
                    city = '', 
                    region = '', 
                    postal_code = '', 
                    country = '', 
                    email = '', 
                    phone_number = '', 
                    default_courier_account = '', 
                    default_courier_company = '', )
            )
        else:
            return Tracking(
        )
        """

    def testTracking(self):
        """Test Tracking"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.datacollection import Datacollection

class TestDatacollection(unittest.TestCase):
    """Datacollection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Datacollection:
        """Test Datacollection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Datacollection`
        """
        model = Datacollection()
        if include_optional:
            return Datacollection(
                id = 1.337,
                create_id = '',
                create_time = '',
                mod_id = '',
                mod_time = '',
                data_collection_datasets = [
                    icat_plus_client.models.datacollection_data_collection_datasets_inner.datacollection_dataCollectionDatasets_inner(
                        dataset = icat_plus_client.models.datacollection_data_collection_datasets_inner_dataset.datacollection_dataCollectionDatasets_inner_dataset(
                            id = 1.337, 
                            name = '', 
                            start_date = '', 
                            end_date = '', 
                            location = '', 
                            sample_name = '', ), )
                    ]
            )
        else:
            return Datacollection(
                id = 1.337,
        )
        """

    def testDatacollection(self):
        """Test Datacollection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.job import Job

class TestJob(unittest.TestCase):
    """Job unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Job:
        """Test Job
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Job`
        """
        model = Job()
        if include_optional:
            return Job(
                id = '',
                dataset_ids = [
                    ''
                    ],
                sample_ids = [
                    ''
                    ],
                user_names = [
                    ''
                    ],
                investigations = [
                    icat_plus_client.models.job_investigations_inner.job_investigations_inner(
                        _id = '', 
                        name = '', 
                        id = '', )
                    ],
                identifier = '',
                input = None,
                logs = [
                    None
                    ],
                status = '',
                statuses = [
                    ''
                    ],
                steps = [
                    icat_plus_client.models._ewoks__session_id__jobs_put_request_step._ewoks__sessionId__jobs_put_request_step(
                        name = '', 
                        status = '', 
                        message = '', )
                    ],
                job_id = '',
                workflow = None,
                created_at = '',
                updated_at = ''
            )
        else:
            return Job(
        )
        """

    def testJob(self):
        """Test Job"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.cache_api import CacheApi


class TestCacheApi(unittest.TestCase):
    """CacheApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CacheApi()

    def tearDown(self) -> None:
        pass

    def test_cache_get(self) -> None:
        """Test case for cache_get

        Gets the cache of a user given a specific sessionId
        """
        pass

    def test_cache_keys_get(self) -> None:
        """Test case for cache_keys_get

        Gets the keys stored in the cache
        """
        pass

    def test_cache_keys_key_get(self) -> None:
        """Test case for cache_keys_key_get

        Gets the content of a key
        """
        pass

    def test_cache_session_id_post(self) -> None:
        """Test case for cache_session_id_post

        Reloads the cache
        """
        pass

    def test_cache_stats_get(self) -> None:
        """Test case for cache_stats_get

        Gets the statistics for the use of cache
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.instrumentscientist import Instrumentscientist

class TestInstrumentscientist(unittest.TestCase):
    """Instrumentscientist unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Instrumentscientist:
        """Test Instrumentscientist
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Instrumentscientist`
        """
        model = Instrumentscientist()
        if include_optional:
            return Instrumentscientist(
                user = icat_plus_client.models.instrumentscientist_user.instrumentscientist_user(
                    name = '', 
                    full_name = '', ),
                id = '',
                mod_id = '',
                create_id = '',
                mod = icat_plus_client.models.instrumentscientist_mod.instrumentscientist_mod(
                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    user = icat_plus_client.models.instrumentscientist_user.instrumentscientist_user(
                        name = '', 
                        full_name = '', ), ),
                instrument = icat_plus_client.models.instrumentscientist_instrument.instrumentscientist_instrument(
                    name = '', 
                    description = '', )
            )
        else:
            return Instrumentscientist(
        )
        """

    def testInstrumentscientist(self):
        """Test Instrumentscientist"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.doi_data import DoiData

class TestDoiData(unittest.TestCase):
    """DoiData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DoiData:
        """Test DoiData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DoiData`
        """
        model = DoiData()
        if include_optional:
            return DoiData(
                title = '',
                abstract = '',
                dataset_id_list = [
                    1.337
                    ],
                data_collection_id = 1.337,
                keywords = [
                    ''
                    ],
                citation_publication_doi = '',
                reference_urls = [
                    ''
                    ],
                rights = ''
            )
        else:
            return DoiData(
                title = '',
                abstract = '',
        )
        """

    def testDoiData(self):
        """Test DoiData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.ewoks_session_id_jobs_put_request import EwoksSessionIdJobsPutRequest

class TestEwoksSessionIdJobsPutRequest(unittest.TestCase):
    """EwoksSessionIdJobsPutRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EwoksSessionIdJobsPutRequest:
        """Test EwoksSessionIdJobsPutRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EwoksSessionIdJobsPutRequest`
        """
        model = EwoksSessionIdJobsPutRequest()
        if include_optional:
            return EwoksSessionIdJobsPutRequest(
                status = '',
                step = icat_plus_client.models._ewoks__session_id__jobs_put_request_step._ewoks__sessionId__jobs_put_request_step(
                    name = '', 
                    status = '', 
                    message = '', ),
                log = None
            )
        else:
            return EwoksSessionIdJobsPutRequest(
        )
        """

    def testEwoksSessionIdJobsPutRequest(self):
        """Test EwoksSessionIdJobsPutRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.tracking_api import TrackingApi


class TestTrackingApi(unittest.TestCase):
    """TrackingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TrackingApi()

    def tearDown(self) -> None:
        pass

    def test_tracking_session_id_address_get(self) -> None:
        """Test case for tracking_session_id_address_get

        Returns all addresses associated to an user
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_delete(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_delete

        Deletes an existin address
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_get(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_get

        Returns a list of addresses associated to an investigation
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_post(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_post

        Creates a address
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_address_put(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_address_put

        Modifies an existin address
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_delete(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_delete

        Deletes an item
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_put(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_put

        Edits an item
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_post(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_post

        Creates an item associated to a parcel
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_labels_get(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_labels_get

        Returns a file with the labels
        """
        pass

    def test_tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_parcel_status_status_put(self) -> None:
        """Test case for tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_parcel_status_status_put

        Modifies a the status of a parcel
        """
        pass

    def test_tracking_session_id_parcel_get(self) -> None:
        """Test case for tracking_session_id_parcel_get

        Lists parcels
        """
        pass

    def test_tracking_session_id_parcel_post(self) -> None:
        """Test case for tracking_session_id_parcel_post

        It does create or update a new parcel
        """
        pass

    def test_tracking_session_id_parcel_put(self) -> None:
        """Test case for tracking_session_id_parcel_put

        It does create or update a new parcel
        """
        pass

    def test_tracking_session_id_setup_get(self) -> None:
        """Test case for tracking_session_id_setup_get

        Returns the the list of container types and parameters allowed to define experiment and processing plans
        """
        pass

    def test_tracking_session_id_shipment_delete(self) -> None:
        """Test case for tracking_session_id_shipment_delete

        Deletes a shipment
        """
        pass

    def test_tracking_session_id_shipment_get(self) -> None:
        """Test case for tracking_session_id_shipment_get

        Lists shipments associated to an investigation
        """
        pass

    def test_tracking_session_id_shipment_id_shipment_id_parcel_delete(self) -> None:
        """Test case for tracking_session_id_shipment_id_shipment_id_parcel_delete

        Deletes a parcel
        """
        pass

    def test_tracking_session_id_shipment_post(self) -> None:
        """Test case for tracking_session_id_shipment_post

        Creates a shipment associated to an investigation
        """
        pass

    def test_tracking_session_id_shipment_put(self) -> None:
        """Test case for tracking_session_id_shipment_put

        Modifies a shipment associated to an investigation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.users_api import USERSApi


class TestUSERSApi(unittest.TestCase):
    """USERSApi unit test stubs"""

    def setUp(self) -> None:
        self.api = USERSApi()

    def tearDown(self) -> None:
        pass

    def test_users_session_id_preferences_get(self) -> None:
        """Test case for users_session_id_preferences_get

        Returns the list of the user's preferences, user from the sessionId
        """
        pass

    def test_users_session_id_preferences_put(self) -> None:
        """Test case for users_session_id_preferences_put

        Update the user's preferences, user from the sessionId
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.session_session_id_get200_response import SessionSessionIdGet200Response

class TestSessionSessionIdGet200Response(unittest.TestCase):
    """SessionSessionIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SessionSessionIdGet200Response:
        """Test SessionSessionIdGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SessionSessionIdGet200Response`
        """
        model = SessionSessionIdGet200Response()
        if include_optional:
            return SessionSessionIdGet200Response(
                remaining_minutes = 1.337,
                user_name = '',
                affiliation = '',
                email = '',
                full_name = '',
                user = {"sessionId":"b1a04f33-3989-4a12-81b8-6d589ff0c01a","username":"reader","name":"reader","fullName":"Anonymous","lifeTimeMinutes":720,"expirationTime":"2022-11-01T03:57:00.364Z","isAdministrator":false,"isInstrumentScientist":false,"isMinter":false,"usersByPrefix":[]}
            )
        else:
            return SessionSessionIdGet200Response(
        )
        """

    def testSessionSessionIdGet200Response(self):
        """Test SessionSessionIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.user_management_api import UserManagementApi


class TestUserManagementApi(unittest.TestCase):
    """UserManagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserManagementApi()

    def tearDown(self) -> None:
        pass

    def test_catalogue_session_id_instrumentscientist_delete(self) -> None:
        """Test case for catalogue_session_id_instrumentscientist_delete

        It deletes InstrumentScientists
        """
        pass

    def test_catalogue_session_id_instrumentscientist_get(self) -> None:
        """Test case for catalogue_session_id_instrumentscientist_get

        Get all InstrumentScientists
        """
        pass

    def test_catalogue_session_id_instrumentscientist_put(self) -> None:
        """Test case for catalogue_session_id_instrumentscientist_put

        It creates InstrumentScientists
        """
        pass

    def test_catalogue_session_id_user_name_name_instrumentscientist_get(self) -> None:
        """Test case for catalogue_session_id_user_name_name_instrumentscientist_get

        Get instrumentScientist by user name
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.dataacquisition_api_key_base64_post_request import DataacquisitionApiKeyBase64PostRequest

class TestDataacquisitionApiKeyBase64PostRequest(unittest.TestCase):
    """DataacquisitionApiKeyBase64PostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataacquisitionApiKeyBase64PostRequest:
        """Test DataacquisitionApiKeyBase64PostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DataacquisitionApiKeyBase64PostRequest`
        """
        model = DataacquisitionApiKeyBase64PostRequest()
        if include_optional:
            return DataacquisitionApiKeyBase64PostRequest(
                var_base64 = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVQYV2NgYAAAAAMAAWgmWQ0AAAAASUVORK5CYII=',
                usernames = ''
            )
        else:
            return DataacquisitionApiKeyBase64PostRequest(
        )
        """

    def testDataacquisitionApiKeyBase64PostRequest(self):
        """Test DataacquisitionApiKeyBase64PostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.catalogue_api import CatalogueApi


class TestCatalogueApi(unittest.TestCase):
    """CatalogueApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CatalogueApi()

    def tearDown(self) -> None:
        pass

    def test_catalogue_instruments_get(self) -> None:
        """Test case for catalogue_instruments_get

        Returns all instruments
        """
        pass

    def test_catalogue_investigation_name_investigation_name_normalize_get(self) -> None:
        """Test case for catalogue_investigation_name_investigation_name_normalize_get

        Most of users don't write their proposal names using the same convention so it might happen that a given proposal can be written in many different ways. This method will homogenize such name.  Example IH-LS-0001, ihls0001, ih-LS-0001 are normalized like IH-LS-0001.
        """
        pass

    def test_catalogue_parameters_get(self) -> None:
        """Test case for catalogue_parameters_get

        Returns all parameters
        """
        pass

    def test_catalogue_session_id_datacollection_get(self) -> None:
        """Test case for catalogue_session_id_datacollection_get

        Gets all datacollection or for a given datasetId
        """
        pass

    def test_catalogue_session_id_datafile_download_get(self) -> None:
        """Test case for catalogue_session_id_datafile_download_get

        Downloads a file given its filepath.
        """
        pass

    def test_catalogue_session_id_datafile_get(self) -> None:
        """Test case for catalogue_session_id_datafile_get

        Get datafiles for a given dataset id.
        """
        pass

    def test_catalogue_session_id_dataset_get(self) -> None:
        """Test case for catalogue_session_id_dataset_get

        Gets datasets for a given investigationId or for a given datasetIds of for a sampleId or for a beamline
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_id_datacollection_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_id_datacollection_get

        Returns datacollections related to a given dataset along with a datasetId
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_id_datafile_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_id_datafile_get

        Get datafiles for a given dataset id. Method replaced by /catalogue/{sessionId}/datafile
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_ids_dataset_document_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_ids_dataset_document_get

        Get a list of dataset documents from a datasetId list. A dataset document is used for indexing a dataset in elastic search. It unflatters dataset's parameters.
        """
        pass

    def test_catalogue_session_id_dataset_id_dataset_ids_dataset_get(self) -> None:
        """Test case for catalogue_session_id_dataset_id_dataset_ids_dataset_get

        Get a list of dataset from a datasetId list
        """
        pass

    def test_catalogue_session_id_dataset_startdate_start_date_enddate_end_date_dataset_document_get(self) -> None:
        """Test case for catalogue_session_id_dataset_startdate_start_date_enddate_end_date_dataset_document_get

        Get a list of dataset documents by date range. A dataset document is used for indexing a dataset in elastic search. It unflatters dataset's parameters.
        """
        pass

    def test_catalogue_session_id_dataset_timeline_get(self) -> None:
        """Test case for catalogue_session_id_dataset_timeline_get

        Gets datasets timeline for a given investigationId or sampleId
        """
        pass

    def test_catalogue_session_id_datasetparameter_get(self) -> None:
        """Test case for catalogue_session_id_datasetparameter_get

        Returns the parameters
        """
        pass

    def test_catalogue_session_id_datasetparameter_put(self) -> None:
        """Test case for catalogue_session_id_datasetparameter_put

        Update a value of a dataset parameter
        """
        pass

    def test_catalogue_session_id_datasetparameter_values_get(self) -> None:
        """Test case for catalogue_session_id_datasetparameter_values_get

        Returns the values of the parameters
        """
        pass

    def test_catalogue_session_id_files_download_get(self) -> None:
        """Test case for catalogue_session_id_files_download_get

        Download the file associated to a sample
        """
        pass

    def test_catalogue_session_id_files_get(self) -> None:
        """Test case for catalogue_session_id_files_get

        Get the list of the files linked to a sample
        """
        pass

    def test_catalogue_session_id_files_upload_post(self) -> None:
        """Test case for catalogue_session_id_files_upload_post

        Upload a file and information linked to a sample
        """
        pass

    def test_catalogue_session_id_instruments_get(self) -> None:
        """Test case for catalogue_session_id_instruments_get

        Returns all instruments linked to the user
        """
        pass

    def test_catalogue_session_id_investigation_get(self) -> None:
        """Test case for catalogue_session_id_investigation_get

        Get investigations by sessionId
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_investigationusers_delete(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_investigationusers_delete

        Deletes a user from an investigation. Only allowed to PI, LocalContact and Beamline staff
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_investigationusers_get(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_investigationusers_get

        Gets users involved in a investigation
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_investigationusers_post(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_investigationusers_post

        Add users to an investigation. Only allowed to PI, LocalContact and Beamline staff
        """
        pass

    def test_catalogue_session_id_investigation_id_investigation_id_sample_get(self) -> None:
        """Test case for catalogue_session_id_investigation_id_investigation_id_sample_get

        Gets samples for a given investigationId
        """
        pass

    def test_catalogue_session_id_investigation_investigation_id_user_get(self) -> None:
        """Test case for catalogue_session_id_investigation_investigation_id_user_get

        Get user list of ICAT if the user if PI or LocalContact of the investigation, or InstrumentScientist or Administrator
        """
        pass

    def test_catalogue_session_id_investigation_timeline_get(self) -> None:
        """Test case for catalogue_session_id_investigation_timeline_get

        Gets investigation timeline for a given instrumentname
        """
        pass

    def test_catalogue_session_id_sample_parameters_id_put(self) -> None:
        """Test case for catalogue_session_id_sample_parameters_id_put

        Update sample parameter (description only if it is an editable sample or only sample comment)
        """
        pass

    def test_catalogue_session_id_samples_get(self) -> None:
        """Test case for catalogue_session_id_samples_get

        Gets samples
        """
        pass

    def test_catalogue_session_id_samples_sample_id_page_get(self) -> None:
        """Test case for catalogue_session_id_samples_sample_id_page_get

        Gets sample page for a given sample
        """
        pass

    def test_catalogue_session_id_samples_sample_id_sample_parameters_post(self) -> None:
        """Test case for catalogue_session_id_samples_sample_id_sample_parameters_post

        Create sample parameter (description only if it is an editable sample, or sample comment only)
        """
        pass

    def test_catalogue_session_id_user_get(self) -> None:
        """Test case for catalogue_session_id_user_get

        Get user list of ICAT (Restricted to administrators)
        """
        pass

    def test_catalogue_techniques_get(self) -> None:
        """Test case for catalogue_techniques_get

        Returns all techniques
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.sample_metadata_api import SampleMetadataApi


class TestSampleMetadataApi(unittest.TestCase):
    """SampleMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SampleMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_samplemetadata_session_id_samples_delete(self) -> None:
        """Test case for samplemetadata_session_id_samples_delete

        Delete samples with metadata information for the given sampleIds
        """
        pass

    def test_samplemetadata_session_id_samples_files_delete(self) -> None:
        """Test case for samplemetadata_session_id_samples_files_delete

        Delete a metadata file
        """
        pass

    def test_samplemetadata_session_id_samples_files_get(self) -> None:
        """Test case for samplemetadata_session_id_samples_files_get

        Download a metadata file
        """
        pass

    def test_samplemetadata_session_id_samples_files_post(self) -> None:
        """Test case for samplemetadata_session_id_samples_files_post

        Upload one or more new files
        """
        pass

    def test_samplemetadata_session_id_samples_get(self) -> None:
        """Test case for samplemetadata_session_id_samples_get

        Returns the list of the samples with metadata information, user from the sessionId
        """
        pass

    def test_samplemetadata_session_id_samples_post(self) -> None:
        """Test case for samplemetadata_session_id_samples_post

        Creates a new sample
        """
        pass

    def test_samplemetadata_session_id_samples_put(self) -> None:
        """Test case for samplemetadata_session_id_samples_put

        Update an existing sample
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.logbook_session_id_events_patch_request import LogbookSessionIdEventsPatchRequest

class TestLogbookSessionIdEventsPatchRequest(unittest.TestCase):
    """LogbookSessionIdEventsPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogbookSessionIdEventsPatchRequest:
        """Test LogbookSessionIdEventsPatchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogbookSessionIdEventsPatchRequest`
        """
        model = LogbookSessionIdEventsPatchRequest()
        if include_optional:
            return LogbookSessionIdEventsPatchRequest(
                event_ids = [
                    ''
                    ],
                tags = [
                    icat_plus_client.models.tag.tag(
                        _id = 56, 
                        name = '', 
                        color = '', 
                        description = '', 
                        beamline_name = '', 
                        investigation_id = '', )
                    ]
            )
        else:
            return LogbookSessionIdEventsPatchRequest(
        )
        """

    def testLogbookSessionIdEventsPatchRequest(self):
        """Test LogbookSessionIdEventsPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.icat_plus_client.model.userpreferences import Userpreferences

class TestUserpreferences(unittest.TestCase):
    """Userpreferences unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Userpreferences:
        """Test Userpreferences
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Userpreferences`
        """
        model = Userpreferences()
        if include_optional:
            return Userpreferences(
                id = '',
                username = '',
                selection = icat_plus_client.models.userpreferences_selection.userpreferences_selection(
                    dataset_ids = [
                        1.337
                        ], 
                    sample_ids = [
                        1.337
                        ], ),
                logbook_filters = icat_plus_client.models.logbook_filters.logbookFilters(
                    sort_by = '', 
                    sort_order = 1.337, 
                    types = '', ),
                recently_visited = [
                    icat_plus_client.models.recently_visited.recentlyVisited(
                        url = '', 
                        label = '', 
                        target = icat_plus_client.models.target.target(
                            instrument_name = '', 
                            investigation_name = '', 
                            investigation_start_date = '', 
                            investigation_end_date = '', ), )
                    ],
                mxsettings = icat_plus_client.models.mxsettings.mxsettings(
                    auto_processing_ranking_shell = '', 
                    auto_processing_ranking_parameter = '', 
                    auto_processing_ranking_disable_space_group = True, 
                    scan_type_filters = [
                        ''
                        ], 
                    cutoffs = icat_plus_client.models.mxcutoffs.mxcutoffs(
                        completeness = icat_plus_client.models.mxshell.mxshell(
                            inner = 1.337, 
                            outer = 1.337, 
                            overall = 1.337, ), 
                        resolution_limit_low = icat_plus_client.models.mxshell.mxshell(
                            inner = 1.337, 
                            outer = 1.337, 
                            overall = 1.337, ), 
                        resolution_limit_high = , 
                        r_meas_all_i_plus_i_minus = , 
                        mean_i_over_sig_i = , 
                        cc_half = , 
                        cc_ano = , ), ),
                is_grouped_by_sample = True,
                pagination = [
                    icat_plus_client.models.pagination_inner.pagination_inner(
                        key = '', 
                        value = 1.337, )
                    ]
            )
        else:
            return Userpreferences(
                username = '',
        )
        """

    def testUserpreferences(self):
        """Test Userpreferences"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.actions_api import ActionsApi


class TestActionsApi(unittest.TestCase):
    """ActionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ActionsApi()

    def tearDown(self) -> None:
        pass

    def test_actions_session_id_logbook_instrumentname_put(self) -> None:
        """Test case for actions_session_id_logbook_instrumentname_put

        Actions related to the field instrumentName of the logbook
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ICAT+ API

    ICAT+ RESTful API with Swagger

    The version of the OpenAPI document: 1.0.0
    Contact: demariaa@esrf.fr
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from icat_plus_client.api.h5_grove_api import H5GroveApi


class TestH5GroveApi(unittest.TestCase):
    """H5GroveApi unit test stubs"""

    def setUp(self) -> None:
        self.api = H5GroveApi()

    def tearDown(self) -> None:
        pass

    def test_h5grove_attr_get(self) -> None:
        """Test case for h5grove_attr_get

        It redirects to h5grove
        """
        pass

    def test_h5grove_data_get(self) -> None:
        """Test case for h5grove_data_get

        It redirects to h5grove
        """
        pass

    def test_h5grove_meta_get(self) -> None:
        """Test case for h5grove_meta_get

        It redirects to h5grove
        """
        pass

    def test_h5grove_stats_get(self) -> None:
        """Test case for h5grove_stats_get

        It redirects to h5grove
        """
        pass


if __name__ == '__main__':
    unittest.main()
